@@ -2,14 +2,11 @@
 -----------------------------------------------------------------------
 --         FILE:  luaotfload-auxiliary.lua
 --  DESCRIPTION:  part of luaotfload
--- REQUIREMENTS:  luaotfload 2.7
+-- REQUIREMENTS:  luaotfload 2.8
 --       AUTHOR:  Khaled Hosny, Élie Roux, Philipp Gesang
 -----------------------------------------------------------------------
 --
 
---- this file addresses issue #24
---- https://github.com/lualatex/luaotfload/issues/24#
-
 luaotfload                  = luaotfload or { }
 local log                   = luaotfload.log
 local logreport             = log.report
@@ -43,13 +40,11 @@ local luaotfload_callbacks  = { }
 
 local rewrite_fontname = function (tfmdata, specification)
   local format = tfmdata.format or tfmdata.properties.format
-  if format ~= "type1" then
-    if stringfind (specification, " ") then
-      tfmdata.name = stringformat ("%q", specification)
-    else
-      --- other specs should parse just fine
-      tfmdata.name = specification
-    end
+  if stringfind (specification, " ") then
+    tfmdata.name = stringformat ("%q", specification)
+  else
+    --- other specs should parse just fine
+    tfmdata.name = specification
   end
 end
 
