@@ -6,7 +6,8 @@ $mirrors = {
     'South Africa' => {
       'http://ctan.mirror.ac.za/' => 1,
       'http://ftp.leg.uct.ac.za/pub/packages/ctan/' => 1,
-      'http://ftp.sun.ac.za/ftp/CTAN/' => 1
+      'http://ftp.sun.ac.za/ftp/CTAN/' => 1,
+      'http://mirror.ufs.ac.za/ctan/' => 1
     }
   },
   'Asia' => {
@@ -16,9 +17,6 @@ $mirrors = {
       'http://mirrors.tuna.tsinghua.edu.cn/CTAN/' => 1,
       'http://mirrors.ustc.edu.cn/CTAN/' => 1
     },
-    'India' => {
-      'http://ctan.imsc.res.in/' => 1
-    },
     'Iran' => {
       'http://ctan.asis.io/' => 1,
       'http://ctan.um.ac.ir/' => 1,
@@ -31,6 +29,7 @@ $mirrors = {
     },
     'Korea' => {
       'http://ftp.kaist.ac.kr/pub/tex-archive/' => 1,
+      'http://ftp.ktug.org/tex-archive/' => 1,
       'http://ftp.neowiz.com/CTAN/' => 1
     },
     'Malaysia' => {
@@ -73,8 +72,8 @@ $mirrors = {
       'ftp://ftp.tu-chemnitz.de/pub/tex/' => 1,
       'http://ctan.space-pro.be/tex-archive/' => 1,
       'http://ftp.fau.de/ctan/' => 1,
-      'http://mirror.physik-pool.tu-berlin.de/tex-archive/' => 1,
-      'http://vesta.informatik.rwth-aachen.de/ftp/pub/mirror/ctan/' => 1
+      'http://vesta.informatik.rwth-aachen.de/ftp/pub/mirror/ctan/' => 1,
+      'http://www.bothelp.net/mirrors/ctan/' => 1
     },
     'Greece' => {
       'http://ftp.cc.uoc.gr/mirrors/CTAN/' => 1
@@ -84,7 +83,6 @@ $mirrors = {
     },
     'Netherlands' => {
       'http://ctan.cs.uu.nl/' => 1,
-      'http://ctan.triasinformatica.nl/' => 1,
       'http://ftp.snt.utwente.nl/pub/software/tex/' => 1
     },
     'Norway' => {
@@ -98,7 +96,6 @@ $mirrors = {
     'Portugal' => {
       'ftp://ftp.di.uminho.pt/pub/ctan/' => 1,
       'ftp://ftp.ist.utl.pt/pub/ctan/' => 1,
-      'http://ftp.eq.uc.pt/software/TeX/' => 1,
       'http://mirrors.fe.up.pt/pub/CTAN/' => 1
     },
     'Russia' => {
@@ -146,7 +143,6 @@ $mirrors = {
     },
     'USA' => {
       'http://ctan.mackichan.com/' => 1,
-      'http://ctan.math.washington.edu/tex-archive/' => 1,
       'http://ctan.mirrors.hoobly.com/' => 1,
       'http://ctan.sharelatex.com/tex-archive/' => 1,
       'http://mirror.hmc.edu/ctan/' => 1,
